==> dd_taoke_sdk-0.2.2.tar.gz: lib/model/halfday_result.dart <==
// To parse this JSON data, do
//
//     final halfdayResult = halfdayResultFromJson(jsonString);

import 'dart:convert';

HalfdayResult halfdayResultFromJson(String str) =>
    HalfdayResult.fromJson(json.decode(str));

String halfdayResultToJson(HalfdayResult data) => json.encode(data.toJson());

class HalfdayResult {
  HalfdayResult({
    this.halfPriceInfo,
    this.sessionsList,
  });

  HalfPriceInfo halfPriceInfo;
  List<SessionsList> sessionsList;

  factory HalfdayResult.fromJson(Map<String, dynamic> json) => HalfdayResult(
        halfPriceInfo: HalfPriceInfo.fromJson(json["halfPriceInfo"]),
        sessionsList: List<SessionsList>.from(
            json["sessionsList"].map((x) => SessionsList.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "halfPriceInfo": halfPriceInfo.toJson(),
        "sessionsList": List<dynamic>.from(sessionsList.map((x) => x.toJson())),
      };
}

class HalfPriceInfo {
  HalfPriceInfo({
    this.banner,
    this.list,
  });

  String banner;
  List<ListElement> list;

  factory HalfPriceInfo.fromJson(Map<String, dynamic> json) => HalfPriceInfo(
        banner: json["banner"],
        list: List<ListElement>.from(
            json["list"].map((x) => ListElement.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "banner": banner,
        "list": List<dynamic>.from(list.map((x) => x.toJson())),
      };
}

class ListElement {
  ListElement({
    this.commissionRate,
    this.todaySellNum,
    this.restCount,
    this.updateTime,
    this.hdLeixing,
    this.itemId,
    this.picUrl,
    this.preferential,
    this.activityId,
    this.yijuhua,
    this.couponAmount,
    this.isMamaQuan,
    this.qiangNum,
    this.top,
    this.useQuan,
    this.price,
    this.name,
    this.startTime,
    this.serverTime,
    this.id,
    this.itemSoldNum,
    this.activityType,
    this.tmall,
  });

  double commissionRate;
  String todaySellNum;
  int restCount;
  DateTime updateTime;
  int hdLeixing;
  String itemId;
  String picUrl;
  Preferential preferential;
  int activityId;
  String yijuhua;
  int couponAmount;
  int isMamaQuan;
  int qiangNum;
  int top;
  int useQuan;
  double price;
  String name;
  DateTime startTime;
  DateTime serverTime;
  int id;
  int itemSoldNum;
  int activityType;
  int tmall;

  factory ListElement.fromJson(Map<String, dynamic> json) => ListElement(
        commissionRate: json["commissionRate"].toDouble(),
        todaySellNum: json["todaySellNum"],
        restCount: json["restCount"],
        updateTime: DateTime.parse(json["updateTime"]),
        hdLeixing: json["hdLeixing"],
        itemId: json["itemId"],
        picUrl: json["picUrl"],
        preferential: preferentialValues.map[json["preferential"]],
        activityId: json["activityId"],
        yijuhua: json["yijuhua"],
        couponAmount: json["couponAmount"] is double
            ? (json["couponAmount"] as double).round()
            : json["couponAmount"],
        isMamaQuan: json["isMamaQuan"],
        qiangNum: json["qiangNum"] == null ? null : json["qiangNum"],
        top: json["top"],
        useQuan: json["useQuan"],
        price: json["price"].toDouble(),
        name: json["name"],
        startTime: DateTime.parse(json["startTime"]),
        serverTime: DateTime.parse(json["serverTime"]),
        id: json["id"],
        itemSoldNum: json["itemSoldNum"],
        activityType: json["activityType"],
        tmall: json["tmall"],
      );

  Map<String, dynamic> toJson() => {
        "commissionRate": commissionRate,
        "todaySellNum": todaySellNum,
        "restCount": restCount,
        "updateTime": updateTime.toIso8601String(),
        "hdLeixing": hdLeixing,
        "itemId": itemId,
        "picUrl": picUrl,
        "preferential": preferentialValues.reverse[preferential],
        "activityId": activityId,
        "yijuhua": yijuhua,
        "couponAmount": couponAmount,
        "isMamaQuan": isMamaQuan,
        "qiangNum": qiangNum == null ? null : qiangNum,
        "top": top,
        "useQuan": useQuan,
        "price": price,
        "name": name,
        "startTime": startTime.toIso8601String(),
        "serverTime": serverTime.toIso8601String(),
        "id": id,
        "itemSoldNum": itemSoldNum,
        "activityType": activityType,
        "tmall": tmall,
      };
}

enum Preferential { EMPTY, PREFERENTIAL }

final preferentialValues =
    EnumValues({"拍下半价": Preferential.EMPTY, "买一送一": Preferential.PREFERENTIAL});

class SessionsList {
  SessionsList({
    this.hpdTime,
    this.status,
  });

  String hpdTime;
  String status;

  factory SessionsList.fromJson(Map<String, dynamic> json) => SessionsList(
        hpdTime: json["hpdTime"],
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "hpdTime": hpdTime,
        "status": status,
      };
}

class EnumValues<T> {
  Map<String, T> map;
  Map<T, String> reverseMap;

  EnumValues(this.map);

  Map<T, String> get reverse {
    if (reverseMap == null) {
      reverseMap = map.map((k, v) => new MapEntry(v, k));
    }
    return reverseMap;
  }
}

==> dd_taoke_sdk-1.2.2.tar.gz: lib/model/halfday_result.dart <==
// To parse this JSON data, do
//
//     final halfdayResult = halfdayResultFromJson(jsonString);

import 'dart:convert';

HalfdayResult halfdayResultFromJson(String str) =>
    HalfdayResult.fromJson(json.decode(str));

String halfdayResultToJson(HalfdayResult data) => json.encode(data.toJson());

class HalfdayResult {
  HalfdayResult({
    this.halfPriceInfo,
    this.sessionsList,
  });

  HalfPriceInfo? halfPriceInfo;
  List<SessionsList>? sessionsList;

  factory HalfdayResult.fromJson(Map<String, dynamic> json) => HalfdayResult(
        halfPriceInfo: HalfPriceInfo.fromJson(json["halfPriceInfo"]),
        sessionsList: List<SessionsList>.from(
            json["sessionsList"].map((x) => SessionsList.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "halfPriceInfo": halfPriceInfo!.toJson(),
        "sessionsList": List<dynamic>.from(sessionsList!.map((x) => x.toJson())),
      };
}

class HalfPriceInfo {
  HalfPriceInfo({
    this.banner,
    this.list,
  });

  String? banner;
  List<ListElement>? list;

  factory HalfPriceInfo.fromJson(Map<String, dynamic> json) => HalfPriceInfo(
        banner: json["banner"],
        list: List<ListElement>.from(
            json["list"].map((x) => ListElement.fromJson(x))),
      );

  Map<String, dynamic> toJson() => {
        "banner": banner,
        "list": List<dynamic>.from(list!.map((x) => x.toJson())),
      };
}

class ListElement {
  ListElement({
    this.commissionRate,
    this.todaySellNum,
    this.restCount,
    this.updateTime,
    this.hdLeixing,
    this.itemId,
    this.picUrl,
    this.preferential,
    this.activityId,
    this.yijuhua,
    this.couponAmount,
    this.isMamaQuan,
    this.qiangNum,
    this.top,
    this.useQuan,
    this.price,
    this.name,
    this.startTime,
    this.serverTime,
    this.id,
    this.itemSoldNum,
    this.activityType,
    this.tmall,
  });

  double? commissionRate;
  String? todaySellNum;
  int? restCount;
  DateTime? updateTime;
  int? hdLeixing;
  String? itemId;
  String? picUrl;
  Preferential? preferential;
  int? activityId;
  String? yijuhua;
  int? couponAmount;
  int? isMamaQuan;
  int? qiangNum;
  int? top;
  int? useQuan;
  double? price;
  String? name;
  DateTime? startTime;
  DateTime? serverTime;
  int? id;
  int? itemSoldNum;
  int? activityType;
  int? tmall;

  factory ListElement.fromJson(Map<String, dynamic> json) => ListElement(
        commissionRate: json["commissionRate"].toDouble(),
        todaySellNum: json["todaySellNum"],
        restCount: json["restCount"],
        updateTime: DateTime.parse(json["updateTime"]),
        hdLeixing: json["hdLeixing"],
        itemId: json["itemId"],
        picUrl: json["picUrl"],
        preferential: preferentialValues.map[json["preferential"]],
        activityId: json["activityId"],
        yijuhua: json["yijuhua"],
        couponAmount: json["couponAmount"] is double
            ? (json["couponAmount"] as double).round()
            : json["couponAmount"],
        isMamaQuan: json["isMamaQuan"],
        qiangNum: json["qiangNum"] == null ? null : json["qiangNum"],
        top: json["top"],
        useQuan: json["useQuan"],
        price: json["price"].toDouble(),
        name: json["name"],
        startTime: DateTime.parse(json["startTime"]),
        serverTime: DateTime.parse(json["serverTime"]),
        id: json["id"],
        itemSoldNum: json["itemSoldNum"],
        activityType: json["activityType"],
        tmall: json["tmall"],
      );

  Map<String, dynamic> toJson() => {
        "commissionRate": commissionRate,
        "todaySellNum": todaySellNum,
        "restCount": restCount,
        "updateTime": updateTime!.toIso8601String(),
        "hdLeixing": hdLeixing,
        "itemId": itemId,
        "picUrl": picUrl,
        "preferential": preferentialValues.reverse![preferential!],
        "activityId": activityId,
        "yijuhua": yijuhua,
        "couponAmount": couponAmount,
        "isMamaQuan": isMamaQuan,
        "qiangNum": qiangNum == null ? null : qiangNum,
        "top": top,
        "useQuan": useQuan,
        "price": price,
        "name": name,
        "startTime": startTime!.toIso8601String(),
        "serverTime": serverTime!.toIso8601String(),
        "id": id,
        "itemSoldNum": itemSoldNum,
        "activityType": activityType,
        "tmall": tmall,
      };
}

enum Preferential { EMPTY, PREFERENTIAL }

final preferentialValues =
    EnumValues({"拍下半价": Preferential.EMPTY, "买一送一": Preferential.PREFERENTIAL});

class SessionsList {
  SessionsList({
    this.hpdTime,
    this.status,
  });

  String? hpdTime;
  String? status;

  factory SessionsList.fromJson(Map<String, dynamic> json) => SessionsList(
        hpdTime: json["hpdTime"],
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "hpdTime": hpdTime,
        "status": status,
      };
}

class EnumValues<T> {
  Map<String, T> map;
  Map<T, String>? reverseMap;

  EnumValues(this.map);

  Map<T, String>? get reverse {
    if (reverseMap == null) {
      reverseMap = map.map((k, v) => new MapEntry(v, k));
    }
    return reverseMap;
  }
}
